=========
Reference
=========

.. autosummary::

   kaczmarz.Base
   kaczmarz.Cyclic
   kaczmarz.MaxDistance

.. autoclass:: kaczmarz.Base
   :members:
   :member-order: bysource

   .. automethod:: kaczmarz.Base._select_row_index

.. autoclass:: kaczmarz.Cyclic
   :members:
   :member-order: bysource
   :show-inheritance:

.. autoclass:: kaczmarz.MaxDistance
   :members:
   :member-order: bysource
   :show-inheritance:
